@@ -1,7 +1,7 @@
 # Kernel of the abstract interpreter of C language.
 #
 # Author::    Yutaka Yanoh <mailto:yanoh@users.sourceforge.net>
-# Copyright:: Copyright (C) 2010-2013, OGIS-RI Co.,Ltd.
+# Copyright:: Copyright (C) 2010-2014, OGIS-RI Co.,Ltd.
 # License::   GPLv3+: GNU General Public License version 3 or later
 #
 # Owner::     Yutaka Yanoh <mailto:yanoh@users.sourceforge.net>
@@ -11,7 +11,7 @@
 #    /   |  / _  |/ /   / / | / /__  __/           Source Code Static Analyzer
 #   / /| | / / / / /   / /  |/ /  / /                   AdLint - Advanced Lint
 #  / __  |/ /_/ / /___/ / /|  /  / /
-# /_/  |_|_____/_____/_/_/ |_/  /_/   Copyright (C) 2010-2013, OGIS-RI Co.,Ltd.
+# /_/  |_|_____/_____/_/_/ |_/  /_/   Copyright (C) 2010-2014, OGIS-RI Co.,Ltd.
 #
 # This file is part of AdLint.
 #
@@ -74,9 +74,9 @@ module Cc1 #:nodoc:
     include InterpreterOptions
     include BranchOptions
 
-    def initialize(type_tbl)
+    def initialize(type_tbl, env = nil)
       @type_table    = type_tbl
-      @environment   = Environment.new(type_tbl)
+      @environment   = env || Environment.new(type_tbl)
       @type_resolver = DynamicTypeResolver.new(type_tbl, self)
 
       @sub_interpreters = [
@@ -182,12 +182,36 @@ module Cc1 #:nodoc:
     #       implicit function.
     def_plugin_and_notifier :implicit_function_declared, :obj_spec, :fun
 
+    # NOTE: Notified when the interpreter evaluates an error-expression.
+    def_plugin_and_notifier :error_expr_evaled, :expr, :rslt_var
+
+    # NOTE: Notified when the interpreter evaluates an object-specifier.
+    def_plugin_and_notifier :object_specifier_evaled, :expr, :rslt_obj
+
+    # NOTE: Notified when the interpreter evaluates a constant-specifier.
+    def_plugin_and_notifier :constant_specifier_evaled, :expr, :rslt_var
+
+    # NOTE: Notified when the interpreter evaluates a string-literal-specifier.
+    def_plugin_and_notifier :string_literal_specifier_evaled, :expr, :rslt_var
+
+    # NOTE: Notified when the interpreter evaluates a null-constant-specifier.
+    def_plugin_and_notifier :null_constant_specifier_evaled, :expr, :rslt_var
+
     # NOTE: Notified when the interpreter evaluates a sizeof-expression.
     def_plugin_and_notifier :sizeof_expr_evaled, :expr, :ope_var, :rslt_var
 
     # NOTE: Notified when the interpreter evaluates a sizeof-type-expression.
     def_plugin_and_notifier :sizeof_type_expr_evaled, :expr, :type, :rslt_var
 
+    # NOTE: Notified when the interpreter evaluates an alignof-expression.
+    def_plugin_and_notifier :alignof_expr_evaled, :expr, :ope_var, :rslt_var
+
+    # NOTE: Notified when the interpreter evaluates an alignof-type-expression.
+    def_plugin_and_notifier :alignof_type_expr_evaled, :expr, :type, :rslt_var
+
+    # NOTE: Notified when the interpreter evaluates a cast-expression.
+    def_plugin_and_notifier :cast_expr_evaled, :expr, :ope_var, :rslt_var
+
     # NOTE: Notified when the interpreter evaluates a cast-expression.
     def_plugin_and_notifier :explicit_conv_performed,
                             :expr, :orig_var, :rslt_var
@@ -276,6 +300,12 @@ module Cc1 #:nodoc:
     def_plugin_and_notifier :member_access_expr_evaled,
                             :expr, :outer_var, :inner_var
 
+    # NOTE: Notified when the interpreter evaluates a
+    #       bit-access-by-value-expression or a
+    #       bit-access-by-pointer-expression.
+    def_plugin_and_notifier :bit_access_expr_evaled,
+                            :expr, :outer_var, :inner_var
+
     # NOTE: Notified when the interpreter evaluates a
     #       prefix-increment-expression.
     def_plugin_and_notifier :prefix_increment_expr_evaled,
@@ -296,6 +326,10 @@ module Cc1 #:nodoc:
     def_plugin_and_notifier :postfix_decrement_expr_evaled,
                             :expr, :ope_var, :rslt_var
 
+    # NOTE: Notified when the interpreter evaluates a
+    #       compound-literal-expression.
+    def_plugin_and_notifier :compound_literal_expr_evaled, :expr, :rslt_var
+
     # NOTE: Notified when the interpreter evaluates a
     #       simple-assignment-expression or a compound-assignment-expression.
     def_plugin_and_notifier :assignment_expr_evaled, :expr, :lhs_var, :rhs_var
@@ -419,7 +453,7 @@ module Cc1 #:nodoc:
 
     def execute(node, *opts)
       @options_stack.push(cur_opts + opts)
-      if quiet_without_side_effect?
+      if without_side_effects?
         rslt = nil
         branched_eval(nil, FINAL) do
           rslt = node.accept(interpreter_for(node))
@@ -435,7 +469,7 @@ module Cc1 #:nodoc:
     end
 
     def quiet?
-      cur_opts.include?(QUIET) || cur_opts.include?(QUIET_WITHOUT_SIDE_EFFECT)
+      cur_opts.include?(QUIET)
     end
 
     def _quiet=(quiet)
@@ -447,16 +481,16 @@ module Cc1 #:nodoc:
       end
     end
 
-    def quiet_without_side_effect?
-      cur_opts.include?(QUIET_WITHOUT_SIDE_EFFECT)
+    def without_side_effects?
+      cur_opts.include?(WITHOUT_SIDE_EFFECTS)
     end
 
-    def _quiet_without_side_effect=(quiet_without_side_effect)
+    def _without_side_effects=(without_side_effects)
       # NOTE: This method is called only from ExpressionEvaluator.
-      if quiet_without_side_effect
-        cur_opts.add(QUIET_WITHOUT_SIDE_EFFECT)
+      if without_side_effects
+        cur_opts.add(WITHOUT_SIDE_EFFECTS)
       else
-        cur_opts.delete(QUIET_WITHOUT_SIDE_EFFECT)
+        cur_opts.delete(WITHOUT_SIDE_EFFECTS)
       end
     end
 
