@@ -1,7 +1,7 @@
 # Miscellaneous option constants.
 #
 # Author::    Yutaka Yanoh <mailto:yanoh@users.sourceforge.net>
-# Copyright:: Copyright (C) 2010-2013, OGIS-RI Co.,Ltd.
+# Copyright:: Copyright (C) 2010-2014, OGIS-RI Co.,Ltd.
 # License::   GPLv3+: GNU General Public License version 3 or later
 #
 # Owner::     Yutaka Yanoh <mailto:yanoh@users.sourceforge.net>
@@ -11,7 +11,7 @@
 #    /   |  / _  |/ /   / / | / /__  __/           Source Code Static Analyzer
 #   / /| | / / / / /   / /  |/ /  / /                   AdLint - Advanced Lint
 #  / __  |/ /_/ / /___/ / /|  /  / /
-# /_/  |_|_____/_____/_/_/ |_/  /_/   Copyright (C) 2010-2013, OGIS-RI Co.,Ltd.
+# /_/  |_|_____/_____/_/_/ |_/  /_/   Copyright (C) 2010-2014, OGIS-RI Co.,Ltd.
 #
 # This file is part of AdLint.
 #
@@ -34,7 +34,7 @@ module Cc1 #:nodoc:
 
   module InterpreterOptions
     QUIET = :quiet
-    QUIET_WITHOUT_SIDE_EFFECT = :quiet_without_side_effect
+    WITHOUT_SIDE_EFFECTS = :without_side_effects
   end
 
   module BranchOptions
