@@ -1,7 +1,7 @@
 # Values associated with memory blocks.
 #
 # Author::    Yutaka Yanoh <mailto:yanoh@users.sourceforge.net>
-# Copyright:: Copyright (C) 2010-2013, OGIS-RI Co.,Ltd.
+# Copyright:: Copyright (C) 2010-2014, OGIS-RI Co.,Ltd.
 # License::   GPLv3+: GNU General Public License version 3 or later
 #
 # Owner::     Yutaka Yanoh <mailto:yanoh@users.sourceforge.net>
@@ -11,7 +11,7 @@
 #    /   |  / _  |/ /   / / | / /__  __/           Source Code Static Analyzer
 #   / /| | / / / / /   / /  |/ /  / /                   AdLint - Advanced Lint
 #  / __  |/ /_/ / /___/ / /|  /  / /
-# /_/  |_|_____/_____/_/_/ |_/  /_/   Copyright (C) 2010-2013, OGIS-RI Co.,Ltd.
+# /_/  |_|_____/_____/_/_/ |_/  /_/   Copyright (C) 2010-2014, OGIS-RI Co.,Ltd.
 #
 # This file is part of AdLint.
 #
@@ -380,7 +380,7 @@ module Cc1 #:nodoc:
 
     private
     def scalar_value_of_null
-      ScalarValue.of(0, logical_shr?)
+      ScalarValue.of_null(logical_shr?)
     end
 
     def scalar_value_of_true
@@ -439,6 +439,12 @@ module Cc1 #:nodoc:
       of(0, logical_shr)
     end
 
+    def of_null(logical_shr)
+      # TODO: NULL may not be 0 on some environments. Representation of NULL
+      #       should be configurable?
+      of(0, logical_shr)
+    end
+
     def of_arbitrary(logical_shr)
       new(ValueDomain.of_unlimited(logical_shr))
     end
@@ -2750,7 +2756,7 @@ module Cc1 #:nodoc:
     end
 
     def active_versioning_groups
-      @versioning_group_stack[1..-1]
+      @versioning_group_stack.drop(1)
     end
 
     def current_versioning_group
