@@ -1,7 +1,7 @@
 # C preprocessor.
 #
 # Author::    Yutaka Yanoh <mailto:yanoh@users.sourceforge.net>
-# Copyright:: Copyright (C) 2010-2013, OGIS-RI Co.,Ltd.
+# Copyright:: Copyright (C) 2010-2014, OGIS-RI Co.,Ltd.
 # License::   GPLv3+: GNU General Public License version 3 or later
 #
 # Owner::     Yutaka Yanoh <mailto:yanoh@users.sourceforge.net>
@@ -11,7 +11,7 @@
 #    /   |  / _  |/ /   / / | / /__  __/           Source Code Static Analyzer
 #   / /| | / / / / /   / /  |/ /  / /                   AdLint - Advanced Lint
 #  / __  |/ /_/ / /___/ / /|  /  / /
-# /_/  |_|_____/_____/_/_/ |_/  /_/   Copyright (C) 2010-2013, OGIS-RI Co.,Ltd.
+# /_/  |_|_____/_____/_/_/ |_/  /_/   Copyright (C) 2010-2014, OGIS-RI Co.,Ltd.
 #
 # This file is part of AdLint.
 #
@@ -441,13 +441,13 @@ module Cpp #:nodoc:
         repl_list = replacement_list(pp_ctxt)
         discard_extra_tokens_until_newline(pp_ctxt)
         if ellipsis
-          define_line = VaFunctionLikeDefineLine.new(keyword, id, id_list,
-                                                     repl_list, sym)
-          macro = FunctionLikeMacro.new(define_line)
+          define_line =
+            VaFunctionLikeDefineLine.new(keyword, id, id_list, repl_list, sym)
+          macro = VaFunctionLikeMacro.new(define_line)
           notify_va_function_like_macro_defined(define_line, macro)
         else
-          define_line = FunctionLikeDefineLine.new(keyword, id, id_list,
-                                                   repl_list, sym)
+          define_line =
+            FunctionLikeDefineLine.new(keyword, id, id_list, repl_list, sym)
           macro = FunctionLikeMacro.new(define_line)
           notify_function_like_macro_defined(define_line, macro)
         end
@@ -994,7 +994,7 @@ module Cpp #:nodoc:
 
         # NOTE: It's not completed when a new-line appears after the macro
         #       name.
-        return false unless pp_toks[idx..-1].any? { |t| t.value == "(" }
+        return false unless pp_toks.drop(idx).any? { |t| t.value == "(" }
 
         paren_cnt = 0
         while tok = pp_toks[idx]
