@@ -1,7 +1,7 @@
 # Lexical analyzer which tokenizes C language source into pp-tokens.
 #
 # Author::    Yutaka Yanoh <mailto:yanoh@users.sourceforge.net>
-# Copyright:: Copyright (C) 2010-2013, OGIS-RI Co.,Ltd.
+# Copyright:: Copyright (C) 2010-2014, OGIS-RI Co.,Ltd.
 # License::   GPLv3+: GNU General Public License version 3 or later
 #
 # Owner::     Yutaka Yanoh <mailto:yanoh@users.sourceforge.net>
@@ -11,7 +11,7 @@
 #    /   |  / _  |/ /   / / | / /__  __/           Source Code Static Analyzer
 #   / /| | / / / / /   / /  |/ /  / /                   AdLint - Advanced Lint
 #  / __  |/ /_/ / /___/ / /|  /  / /
-# /_/  |_|_____/_____/_/_/ |_/  /_/   Copyright (C) 2010-2013, OGIS-RI Co.,Ltd.
+# /_/  |_|_____/_____/_/_/ |_/  /_/   Copyright (C) 2010-2014, OGIS-RI Co.,Ltd.
 #
 # This file is part of AdLint.
 #
@@ -160,7 +160,17 @@ module Cpp #:nodoc:
     private_constant :GROUP_DIRECTIVE_RE
 
     def scan_until_next_directive_or_comment(cont)
-      cont.scan(/.*?(?=#{GROUP_DIRECTIVE_RE}|\/\*|\/\/)/m)
+      until cont.empty?
+        cont.scan(/.*?(?=#{GROUP_DIRECTIVE_RE}|"|'|\/\*|\/\/)/m)
+        case
+        when cont.check(/"/)
+          Language::C::scan_string_literal(cont)
+        when cont.check(/'/)
+          Language::C::scan_char_constant(cont)
+        else
+          break
+        end
+      end
     end
 
     def scan_block_comment(cont)
