@@ -1,7 +1,7 @@
 # C preprocessor macros.
 #
 # Author::    Yutaka Yanoh <mailto:yanoh@users.sourceforge.net>
-# Copyright:: Copyright (C) 2010-2013, OGIS-RI Co.,Ltd.
+# Copyright:: Copyright (C) 2010-2014, OGIS-RI Co.,Ltd.
 # License::   GPLv3+: GNU General Public License version 3 or later
 #
 # Owner::     Yutaka Yanoh <mailto:yanoh@users.sourceforge.net>
@@ -11,7 +11,7 @@
 #    /   |  / _  |/ /   / / | / /__  __/           Source Code Static Analyzer
 #   / /| | / / / / /   / /  |/ /  / /                   AdLint - Advanced Lint
 #  / __  |/ /_/ / /___/ / /|  /  / /
-# /_/  |_|_____/_____/_/_/ |_/  /_/   Copyright (C) 2010-2013, OGIS-RI Co.,Ltd.
+# /_/  |_|_____/_____/_/_/ |_/  /_/   Copyright (C) 2010-2014, OGIS-RI Co.,Ltd.
 #
 # This file is part of AdLint.
 #
@@ -109,16 +109,16 @@ module Cpp #:nodoc:
     attr_reader :parameter_names
 
     def replaceable_size(toks)
-      return 0 unless name.value == toks.first.value
-      args, idx = parse_arguments(toks, 1)
-      case
-      when args && @parameter_names.empty?
-        idx + 1
-      when args && @parameter_names.size >= args.size
-        idx + 1
-      else
-        0
+      if name.value == toks.first.value
+        args, idx = parse_arguments(toks, 1)
+        case
+        when args && @parameter_names.empty?
+          return idx + 1
+        when args && @parameter_names.size >= args.size
+          return idx + 1
+        end
       end
+      0
     end
 
     def expand(toks, macro_tbl, repl_ctxt)
@@ -394,6 +394,45 @@ module Cpp #:nodoc:
     end
   end
 
+  class VaFunctionLikeMacro < FunctionLikeMacro
+    def replaceable_size(toks)
+      if name.value == toks.first.value
+        args, idx = parse_arguments(toks, 1)
+        args ? idx + 1 : 0
+      else
+        0
+      end
+    end
+
+    def expand(toks, macro_tbl, repl_ctxt)
+      super
+
+      all_args, * = parse_arguments(toks, 1)
+      args = all_args.shift(@parameter_names.size)
+      rest_args = all_args
+
+      args_hash =
+        @parameter_names.zip(args).each_with_object({}) { |(param, arg), hash|
+          hash[param] = arg
+        }
+
+      va_args = args_hash["__VA_ARGS__"] = []
+      unless rest_args.empty?
+        va_args.concat(rest_args.shift)
+        rest_args.each do |arg|
+          va_args.push(ReplacedToken.new(:PP_TOKEN, ",", Location.new))
+          va_args.concat(arg)
+        end
+      end
+
+      rslt_toks = expand_replacement_list(args_hash, toks.first.location,
+                                          macro_tbl, repl_ctxt)
+      macro_tbl.notify_function_like_macro_replacement(self, toks, args,
+                                                       rslt_toks)
+      rslt_toks
+    end
+  end
+
   class SpecialMacro < ObjectLikeMacro
     def initialize(name_str)
       super(PseudoObjectLikeDefineLine.new(name_str))
@@ -738,7 +777,7 @@ module Cpp #:nodoc:
       return nil unless tok = toks[idx] and macro = lookup(tok.value)
       return nil if repl_ctxt.hidden?(tok, macro.name.value)
 
-      size = macro.replaceable_size(toks[idx..-1])
+      size = macro.replaceable_size(toks.drop(idx))
 
       if toks[idx, size].all? { |t| t.need_no_further_replacement? }
         return nil
