@@ -1,7 +1,7 @@
 # Code structure extractions (cc1-phase) of adlint-exam-c_builtin package.
 #
 # Author::    Yutaka Yanoh <mailto:yanoh@users.sourceforge.net>
-# Copyright:: Copyright (C) 2010-2013, OGIS-RI Co.,Ltd.
+# Copyright:: Copyright (C) 2010-2014, OGIS-RI Co.,Ltd.
 # License::   GPLv3+: GNU General Public License version 3 or later
 #
 # Owner::     Yutaka Yanoh <mailto:yanoh@users.sourceforge.net>
@@ -11,7 +11,7 @@
 #    /   |  / _  |/ /   / / | / /__  __/           Source Code Static Analyzer
 #   / /| | / / / / /   / /  |/ /  / /                   AdLint - Advanced Lint
 #  / __  |/ /_/ / /___/ / /|  /  / /
-# /_/  |_|_____/_____/_/_/ |_/  /_/   Copyright (C) 2010-2013, OGIS-RI Co.,Ltd.
+# /_/  |_|_____/_____/_/_/ |_/  /_/   Copyright (C) 2010-2014, OGIS-RI Co.,Ltd.
 #
 # This file is part of AdLint.
 #
@@ -38,44 +38,44 @@ module AdLint #:nodoc:
 module Exam #:nodoc:
 module CBuiltin #:nodoc:
 
-  class TypeDeclExtraction < CodeExtraction
+  class TypeDclExtraction < CodeExtraction
     def_registrant_phase Cc1::Prepare2Phase
 
     def initialize(phase_ctxt)
       super
-      traversal = phase_ctxt[:cc1_ast_traversal]
-      traversal.enter_typedef_declaration     += T(:extract_typedef)
-      traversal.enter_struct_type_declaration += T(:extract_struct)
-      traversal.enter_union_type_declaration  += T(:extract_union)
-      traversal.enter_enum_type_declaration   += T(:extract_enum)
+      trav = phase_ctxt[:cc1_ast_traversal]
+      trav.enter_typedef_declaration     += T(:extract_typedef_dcl)
+      trav.enter_struct_type_declaration += T(:extract_struct_dcl)
+      trav.enter_union_type_declaration  += T(:extract_union_dcl)
+      trav.enter_enum_type_declaration   += T(:extract_enum_dcl)
     end
 
     private
     def do_prepare(*) end
     def do_execute(*) end
 
-    def extract_typedef(typedef_dcl)
+    def extract_typedef_dcl(typedef_dcl)
       TYPEDCL(typedef_dcl.identifier.location, "T",
               typedef_dcl.type.name, typedef_dcl.type.image)
     end
 
-    def extract_struct(struct_type_dcl)
+    def extract_struct_dcl(struct_type_dcl)
       TYPEDCL(struct_type_dcl.identifier.location, "S",
               struct_type_dcl.type.name, struct_type_dcl.type.image)
     end
 
-    def extract_union(union_type_dcl)
+    def extract_union_dcl(union_type_dcl)
       TYPEDCL(union_type_dcl.identifier.location, "U",
               union_type_dcl.type.name, union_type_dcl.type.image)
     end
 
-    def extract_enum(enum_type_dcl)
+    def extract_enum_dcl(enum_type_dcl)
       TYPEDCL(enum_type_dcl.identifier.location, "E",
               enum_type_dcl.type.name, enum_type_dcl.type.image)
     end
   end
 
-  class GVarDeclExtraction < CodeExtraction
+  class GVarDclExtraction < CodeExtraction
     def_registrant_phase Cc1::Prepare2Phase
 
     def initialize(phase_ctxt)
@@ -246,8 +246,8 @@ module CBuiltin #:nodoc:
 
     def initialize(phase_ctxt)
       super
-      traversal = phase_ctxt[:cc1_ast_traversal]
-      traversal.enter_generic_labeled_statement += T(:extract)
+      trav = phase_ctxt[:cc1_ast_traversal]
+      trav.enter_generic_labeled_statement += T(:extract)
     end
 
     private
@@ -264,8 +264,8 @@ module CBuiltin #:nodoc:
 
     def initialize(phase_ctxt)
       super
-      traversal = phase_ctxt[:cc1_ast_traversal]
-      traversal.enter_variable_definition += T(:extract)
+      trav = phase_ctxt[:cc1_ast_traversal]
+      trav.enter_variable_definition += T(:extract)
     end
 
     private
@@ -285,9 +285,9 @@ module CBuiltin #:nodoc:
 
     def initialize(phase_ctxt)
       super
-      traversal = phase_ctxt[:cc1_ast_traversal]
-      traversal.enter_simple_assignment_expression   += T(:extract)
-      traversal.enter_compound_assignment_expression += T(:extract)
+      trav = phase_ctxt[:cc1_ast_traversal]
+      trav.enter_simple_assignment_expression   += T(:extract)
+      trav.enter_compound_assignment_expression += T(:extract)
     end
 
     private
@@ -407,8 +407,8 @@ module CBuiltin #:nodoc:
         else
           referrer = FunctionId.of_ctors_section
         end
-        XREF_FUNC(expr.location, referrer, "R",
-                  FunctionId.new(fun.name, fun.signature.to_s))
+        XREF_FUN(expr.location, referrer, "R",
+                 FunctionId.new(fun.name, fun.signature.to_s))
       end
     end
   end
@@ -418,9 +418,9 @@ module CBuiltin #:nodoc:
 
     def initialize(phase_ctxt)
       super
-      traversal = phase_ctxt[:cc1_ast_traversal]
-      traversal.enter_constant_specifier       += T(:extract_constant)
-      traversal.enter_string_literal_specifier += T(:extract_string_literal)
+      trav = phase_ctxt[:cc1_ast_traversal]
+      trav.enter_constant_specifier       += T(:extract_constant)
+      trav.enter_string_literal_specifier += T(:extract_string_literal)
     end
 
     private
