@@ -1,7 +1,7 @@
 # Metric measurements (cc1-phase) of adlint-exam-c_builtin package.
 #
 # Author::    Yutaka Yanoh <mailto:yanoh@users.sourceforge.net>
-# Copyright:: Copyright (C) 2010-2013, OGIS-RI Co.,Ltd.
+# Copyright:: Copyright (C) 2010-2014, OGIS-RI Co.,Ltd.
 # License::   GPLv3+: GNU General Public License version 3 or later
 #
 # Owner::     Yutaka Yanoh <mailto:yanoh@users.sourceforge.net>
@@ -11,7 +11,7 @@
 #    /   |  / _  |/ /   / / | / /__  __/           Source Code Static Analyzer
 #   / /| | / / / / /   / /  |/ /  / /                   AdLint - Advanced Lint
 #  / __  |/ /_/ / /___/ / /|  /  / /
-# /_/  |_|_____/_____/_/_/ |_/  /_/   Copyright (C) 2010-2013, OGIS-RI Co.,Ltd.
+# /_/  |_|_____/_____/_/_/ |_/  /_/   Copyright (C) 2010-2014, OGIS-RI Co.,Ltd.
 #
 # This file is part of AdLint.
 #
@@ -44,24 +44,24 @@ module CBuiltin #:nodoc:
     def initialize(phase_ctxt)
       super
       @fpath = phase_ctxt[:sources].first.fpath
-      traversal = phase_ctxt[:cc1_ast_traversal]
-      traversal.enter_error_statement           += T(:count_statement)
-      traversal.enter_generic_labeled_statement += T(:count_statement)
-      traversal.enter_case_labeled_statement    += T(:count_statement)
-      traversal.enter_default_labeled_statement += T(:count_statement)
-      traversal.enter_expression_statement      += T(:count_statement)
-      traversal.enter_if_statement              += T(:count_statement)
-      traversal.enter_if_else_statement         += T(:count_statement)
-      traversal.enter_switch_statement          += T(:count_statement)
-      traversal.enter_while_statement           += T(:count_statement)
-      traversal.enter_do_statement              += T(:count_statement)
-      traversal.enter_for_statement             += T(:count_statement)
-      traversal.enter_c99_for_statement         += T(:count_statement)
-      traversal.enter_goto_statement            += T(:count_statement)
-      traversal.enter_continue_statement        += T(:count_statement)
-      traversal.enter_break_statement           += T(:count_statement)
-      traversal.enter_return_statement          += T(:count_statement)
-      traversal.leave_translation_unit          += M(:measure)
+      trav = phase_ctxt[:cc1_ast_traversal]
+      trav.enter_error_statement           += T(:count_statement)
+      trav.enter_generic_labeled_statement += T(:count_statement)
+      trav.enter_case_labeled_statement    += T(:count_statement)
+      trav.enter_default_labeled_statement += T(:count_statement)
+      trav.enter_expression_statement      += T(:count_statement)
+      trav.enter_if_statement              += T(:count_statement)
+      trav.enter_if_else_statement         += T(:count_statement)
+      trav.enter_switch_statement          += T(:count_statement)
+      trav.enter_while_statement           += T(:count_statement)
+      trav.enter_do_statement              += T(:count_statement)
+      trav.enter_for_statement             += T(:count_statement)
+      trav.enter_c99_for_statement         += T(:count_statement)
+      trav.enter_goto_statement            += T(:count_statement)
+      trav.enter_continue_statement        += T(:count_statement)
+      trav.enter_break_statement           += T(:count_statement)
+      trav.enter_return_statement          += T(:count_statement)
+      trav.leave_translation_unit          += M(:measure)
       @stmt_cnt = 0
     end
 
@@ -86,10 +86,10 @@ module CBuiltin #:nodoc:
     def initialize(phase_ctxt)
       super
       @fpath = phase_ctxt[:sources].first.fpath
-      traversal = phase_ctxt[:cc1_ast_traversal]
-      traversal.enter_ansi_function_definition  += T(:count_function)
-      traversal.enter_kandr_function_definition += T(:count_function)
-      traversal.leave_translation_unit          += M(:measure)
+      trav = phase_ctxt[:cc1_ast_traversal]
+      trav.enter_ansi_function_definition  += T(:count_function)
+      trav.enter_kandr_function_definition += T(:count_function)
+      trav.leave_translation_unit          += M(:measure)
       @fun_cnt = 0
     end
 
@@ -114,27 +114,27 @@ module CBuiltin #:nodoc:
     def initialize(phase_ctxt)
       super
       @fpath = phase_ctxt[:sources].first.fpath
-      traversal = phase_ctxt[:cc1_ast_traversal]
-      traversal.enter_ansi_function_definition  += T(:enter_function)
-      traversal.leave_ansi_function_definition  += T(:leave_function)
-      traversal.enter_kandr_function_definition += T(:enter_function)
-      traversal.leave_kandr_function_definition += T(:leave_function)
-      traversal.enter_error_statement           += T(:count_statement)
-      traversal.enter_generic_labeled_statement += T(:count_statement)
-      traversal.enter_case_labeled_statement    += T(:count_statement)
-      traversal.enter_default_labeled_statement += T(:count_statement)
-      traversal.enter_expression_statement      += T(:count_statement)
-      traversal.enter_if_statement              += T(:count_statement)
-      traversal.enter_if_else_statement         += T(:count_statement)
-      traversal.enter_switch_statement          += T(:count_statement)
-      traversal.enter_while_statement           += T(:count_statement)
-      traversal.enter_do_statement              += T(:count_statement)
-      traversal.enter_for_statement             += T(:count_statement)
-      traversal.enter_c99_for_statement         += T(:count_statement)
-      traversal.enter_goto_statement            += T(:count_statement)
-      traversal.enter_continue_statement        += T(:count_statement)
-      traversal.enter_break_statement           += T(:count_statement)
-      traversal.enter_return_statement          += T(:count_statement)
+      trav = phase_ctxt[:cc1_ast_traversal]
+      trav.enter_ansi_function_definition  += T(:enter_function)
+      trav.leave_ansi_function_definition  += T(:leave_function)
+      trav.enter_kandr_function_definition += T(:enter_function)
+      trav.leave_kandr_function_definition += T(:leave_function)
+      trav.enter_error_statement           += T(:count_statement)
+      trav.enter_generic_labeled_statement += T(:count_statement)
+      trav.enter_case_labeled_statement    += T(:count_statement)
+      trav.enter_default_labeled_statement += T(:count_statement)
+      trav.enter_expression_statement      += T(:count_statement)
+      trav.enter_if_statement              += T(:count_statement)
+      trav.enter_if_else_statement         += T(:count_statement)
+      trav.enter_switch_statement          += T(:count_statement)
+      trav.enter_while_statement           += T(:count_statement)
+      trav.enter_do_statement              += T(:count_statement)
+      trav.enter_for_statement             += T(:count_statement)
+      trav.enter_c99_for_statement         += T(:count_statement)
+      trav.enter_goto_statement            += T(:count_statement)
+      trav.enter_continue_statement        += T(:count_statement)
+      trav.enter_break_statement           += T(:count_statement)
+      trav.enter_return_statement          += T(:count_statement)
       @cur_fun = nil
       @stmt_cnt = 0
     end
@@ -144,10 +144,8 @@ module CBuiltin #:nodoc:
     def do_execute(*) end
 
     def enter_function(fun_def)
-      if @fpath == fun_def.location.fpath
-        @cur_fun = fun_def
-        @stmt_cnt = 0
-      end
+      @cur_fun = fun_def
+      @stmt_cnt = 0
     end
 
     def leave_function(*)
@@ -172,27 +170,27 @@ module CBuiltin #:nodoc:
     def initialize(phase_ctxt)
       super
       @fpath = phase_ctxt[:sources].first.fpath
-      traversal = phase_ctxt[:cc1_ast_traversal]
-      traversal.enter_ansi_function_definition  += T(:enter_function)
-      traversal.leave_ansi_function_definition  += T(:leave_function)
-      traversal.enter_kandr_function_definition += T(:enter_function)
-      traversal.leave_kandr_function_definition += T(:leave_function)
-      traversal.enter_error_statement           += T(:count_statement)
-      traversal.enter_generic_labeled_statement += T(:count_statement)
-      traversal.enter_case_labeled_statement    += T(:count_statement)
-      traversal.enter_default_labeled_statement += T(:count_statement)
-      traversal.enter_expression_statement      += T(:count_statement)
-      traversal.enter_if_statement              += T(:count_statement)
-      traversal.enter_if_else_statement         += T(:count_statement)
-      traversal.enter_switch_statement          += T(:count_statement)
-      traversal.enter_while_statement           += T(:count_statement)
-      traversal.enter_do_statement              += T(:count_statement)
-      traversal.enter_for_statement             += T(:count_statement)
-      traversal.enter_c99_for_statement         += T(:count_statement)
-      traversal.enter_goto_statement            += T(:count_statement)
-      traversal.enter_continue_statement        += T(:count_statement)
-      traversal.enter_break_statement           += T(:count_statement)
-      traversal.enter_return_statement          += T(:count_statement)
+      trav = phase_ctxt[:cc1_ast_traversal]
+      trav.enter_ansi_function_definition  += T(:enter_function)
+      trav.leave_ansi_function_definition  += T(:leave_function)
+      trav.enter_kandr_function_definition += T(:enter_function)
+      trav.leave_kandr_function_definition += T(:leave_function)
+      trav.enter_error_statement           += T(:count_statement)
+      trav.enter_generic_labeled_statement += T(:count_statement)
+      trav.enter_case_labeled_statement    += T(:count_statement)
+      trav.enter_default_labeled_statement += T(:count_statement)
+      trav.enter_expression_statement      += T(:count_statement)
+      trav.enter_if_statement              += T(:count_statement)
+      trav.enter_if_else_statement         += T(:count_statement)
+      trav.enter_switch_statement          += T(:count_statement)
+      trav.enter_while_statement           += T(:count_statement)
+      trav.enter_do_statement              += T(:count_statement)
+      trav.enter_for_statement             += T(:count_statement)
+      trav.enter_c99_for_statement         += T(:count_statement)
+      trav.enter_goto_statement            += T(:count_statement)
+      trav.enter_continue_statement        += T(:count_statement)
+      trav.enter_break_statement           += T(:count_statement)
+      trav.enter_return_statement          += T(:count_statement)
       @cur_fun = nil
       @unreached_stmt_cnt = 0
     end
@@ -202,10 +200,8 @@ module CBuiltin #:nodoc:
     def do_execute(*) end
 
     def enter_function(fun_def)
-      if @fpath == fun_def.location.fpath
-        @cur_fun = fun_def
-        @unreached_stmt_cnt = 0
-      end
+      @cur_fun = fun_def
+      @unreached_stmt_cnt = 0
     end
 
     def leave_function(*)
@@ -231,9 +227,9 @@ module CBuiltin #:nodoc:
     def initialize(phase_ctxt)
       super
       @fpath = phase_ctxt[:sources].first.fpath
-      traversal = phase_ctxt[:cc1_ast_traversal]
-      traversal.enter_ansi_function_definition  += T(:measure)
-      traversal.enter_kandr_function_definition += T(:measure)
+      trav = phase_ctxt[:cc1_ast_traversal]
+      trav.enter_ansi_function_definition  += T(:measure)
+      trav.enter_kandr_function_definition += T(:measure)
     end
 
     private
@@ -241,11 +237,8 @@ module CBuiltin #:nodoc:
     def do_execute(*) end
 
     def measure(fun_def)
-      if @fpath == fun_def.location.fpath
-        FN_LINE(FunctionId.new(fun_def.identifier.value,
-                               fun_def.signature.to_s),
-                fun_def.location, fun_def.lines)
-      end
+      FN_LINE(FunctionId.new(fun_def.identifier.value, fun_def.signature.to_s),
+              fun_def.location, fun_def.lines)
     end
   end
 
@@ -255,9 +248,9 @@ module CBuiltin #:nodoc:
     def initialize(phase_ctxt)
       super
       @fpath = phase_ctxt[:sources].first.fpath
-      traversal = phase_ctxt[:cc1_ast_traversal]
-      traversal.enter_ansi_function_definition  += T(:measure_ansi_function)
-      traversal.enter_kandr_function_definition += T(:measure_kandr_function)
+      trav = phase_ctxt[:cc1_ast_traversal]
+      trav.enter_ansi_function_definition  += T(:measure_ansi_function)
+      trav.enter_kandr_function_definition += T(:measure_kandr_function)
     end
 
     private
@@ -265,28 +258,23 @@ module CBuiltin #:nodoc:
     def do_execute(*) end
 
     def measure_ansi_function(fun_def)
-      if @fpath == fun_def.location.fpath
-        # TODO: Determine how many parameters if function has va_list.
-        if fun_def.parameter_type_list
-          params = fun_def.parameter_definitions
-          FN_PARA(FunctionId.new(fun_def.identifier.value,
-                                 fun_def.signature.to_s),
-                  fun_def.location, params.count { |param| !param.type.void? })
-        else
-          # TODO: Determine how many parameters if signature is abbreviated.
-          FN_PARA(FunctionId.new(fun_def.identifier.value,
-                                 fun_def.signature.to_s),
-                  fun_def.location, 0)
-        end
+      # TODO: Determine how many parameters if function has va_list.
+      if fun_def.parameter_type_list
+        params = fun_def.parameter_definitions
+        FN_PARA(FunctionId.new(fun_def.identifier.value,
+                               fun_def.signature.to_s),
+                fun_def.location, params.count { |param| !param.type.void? })
+      else
+        # TODO: Determine how many parameters if signature is abbreviated.
+        FN_PARA(FunctionId.new(fun_def.identifier.value,
+                               fun_def.signature.to_s),
+                fun_def.location, 0)
       end
     end
 
     def measure_kandr_function(fun_def)
-      if @fpath == fun_def.location.fpath
-        FN_PARA(FunctionId.new(fun_def.identifier.value,
-                               fun_def.signature.to_s),
-                fun_def.location, fun_def.identifier_list.size)
-      end
+      FN_PARA(FunctionId.new(fun_def.identifier.value, fun_def.signature.to_s),
+              fun_def.location, fun_def.identifier_list.size)
     end
   end
 
@@ -313,10 +301,8 @@ module CBuiltin #:nodoc:
     def do_execute(*) end
 
     def enter_function(fun_def, *)
-      if @fpath == fun_def.location.fpath
-        @cur_fun = fun_def
-        @vars = {}
-      end
+      @cur_fun = fun_def
+      @vars = {}
     end
 
     def leave_function(*)
@@ -364,12 +350,12 @@ module CBuiltin #:nodoc:
     def initialize(phase_ctxt)
       super
       @fpath = phase_ctxt[:sources].first.fpath
-      traversal = phase_ctxt[:cc1_ast_traversal]
-      traversal.enter_ansi_function_definition  += T(:enter_function)
-      traversal.leave_ansi_function_definition  += T(:leave_function)
-      traversal.enter_kandr_function_definition += T(:enter_function)
-      traversal.leave_kandr_function_definition += T(:leave_function)
-      traversal.enter_function_call_expression  += T(:count_function_call)
+      trav = phase_ctxt[:cc1_ast_traversal]
+      trav.enter_ansi_function_definition  += T(:enter_function)
+      trav.leave_ansi_function_definition  += T(:leave_function)
+      trav.enter_kandr_function_definition += T(:enter_function)
+      trav.leave_kandr_function_definition += T(:leave_function)
+      trav.enter_function_call_expression  += T(:count_function_call)
       @cur_fun = nil
       @funcall_cnt = 0
     end
@@ -379,10 +365,8 @@ module CBuiltin #:nodoc:
     def do_execute(*) end
 
     def enter_function(fun_def)
-      if @fpath == fun_def.location.fpath
-        @cur_fun = fun_def
-        @funcall_cnt = 0
-      end
+      @cur_fun = fun_def
+      @funcall_cnt = 0
     end
 
     def leave_function(*)
@@ -408,12 +392,12 @@ module CBuiltin #:nodoc:
     def initialize(phase_ctxt)
       super
       @fpath = phase_ctxt[:sources].first.fpath
-      traversal = phase_ctxt[:cc1_ast_traversal]
-      traversal.enter_ansi_function_definition  += T(:enter_function)
-      traversal.leave_ansi_function_definition  += T(:leave_function)
-      traversal.enter_kandr_function_definition += T(:enter_function)
-      traversal.leave_kandr_function_definition += T(:leave_function)
-      traversal.enter_goto_statement            += T(:count_goto)
+      trav = phase_ctxt[:cc1_ast_traversal]
+      trav.enter_ansi_function_definition  += T(:enter_function)
+      trav.leave_ansi_function_definition  += T(:leave_function)
+      trav.enter_kandr_function_definition += T(:enter_function)
+      trav.leave_kandr_function_definition += T(:leave_function)
+      trav.enter_goto_statement            += T(:count_goto)
       @cur_fun = nil
       @goto_cnt = 0
     end
@@ -423,10 +407,8 @@ module CBuiltin #:nodoc:
     def do_execute(*) end
 
     def enter_function(fun_def)
-      if @fpath == fun_def.location.fpath
-        @cur_fun = fun_def
-        @goto_cnt = 0
-      end
+      @cur_fun = fun_def
+      @goto_cnt = 0
     end
 
     def leave_function(*)
@@ -452,27 +434,27 @@ module CBuiltin #:nodoc:
     def initialize(phase_ctxt)
       super
       @fpath = phase_ctxt[:sources].first.fpath
-      traversal = phase_ctxt[:cc1_ast_traversal]
-      traversal.enter_ansi_function_definition  += T(:enter_function)
-      traversal.leave_ansi_function_definition  += T(:leave_function)
-      traversal.enter_kandr_function_definition += T(:enter_function)
-      traversal.leave_kandr_function_definition += T(:leave_function)
-      traversal.enter_error_statement           += T(:enter_statement)
-      traversal.enter_generic_labeled_statement += T(:enter_statement)
-      traversal.enter_case_labeled_statement    += T(:enter_statement)
-      traversal.enter_default_labeled_statement += T(:enter_statement)
-      traversal.enter_expression_statement      += T(:enter_statement)
-      traversal.enter_if_statement              += T(:enter_statement)
-      traversal.enter_if_else_statement         += T(:enter_statement)
-      traversal.enter_switch_statement          += T(:enter_statement)
-      traversal.enter_while_statement           += T(:enter_statement)
-      traversal.enter_do_statement              += T(:enter_statement)
-      traversal.enter_for_statement             += T(:enter_statement)
-      traversal.enter_c99_for_statement         += T(:enter_statement)
-      traversal.enter_goto_statement            += T(:enter_statement)
-      traversal.enter_continue_statement        += T(:enter_statement)
-      traversal.enter_break_statement           += T(:enter_statement)
-      traversal.enter_return_statement          += T(:count_return)
+      trav = phase_ctxt[:cc1_ast_traversal]
+      trav.enter_ansi_function_definition  += T(:enter_function)
+      trav.leave_ansi_function_definition  += T(:leave_function)
+      trav.enter_kandr_function_definition += T(:enter_function)
+      trav.leave_kandr_function_definition += T(:leave_function)
+      trav.enter_error_statement           += T(:enter_statement)
+      trav.enter_generic_labeled_statement += T(:enter_statement)
+      trav.enter_case_labeled_statement    += T(:enter_statement)
+      trav.enter_default_labeled_statement += T(:enter_statement)
+      trav.enter_expression_statement      += T(:enter_statement)
+      trav.enter_if_statement              += T(:enter_statement)
+      trav.enter_if_else_statement         += T(:enter_statement)
+      trav.enter_switch_statement          += T(:enter_statement)
+      trav.enter_while_statement           += T(:enter_statement)
+      trav.enter_do_statement              += T(:enter_statement)
+      trav.enter_for_statement             += T(:enter_statement)
+      trav.enter_c99_for_statement         += T(:enter_statement)
+      trav.enter_goto_statement            += T(:enter_statement)
+      trav.enter_continue_statement        += T(:enter_statement)
+      trav.enter_break_statement           += T(:enter_statement)
+      trav.enter_return_statement          += T(:count_return)
       @cur_fun  = nil
       @ret_cnt  = 0
       @lst_stmt = nil
@@ -483,11 +465,9 @@ module CBuiltin #:nodoc:
     def do_execute(*) end
 
     def enter_function(fun_def)
-      if @fpath == fun_def.location.fpath
-        @cur_fun  = fun_def
-        @ret_cnt  = 0
-        @lst_stmt = nil
-      end
+      @cur_fun  = fun_def
+      @ret_cnt  = 0
+      @lst_stmt = nil
     end
 
     def leave_function(*)
@@ -528,13 +508,13 @@ module CBuiltin #:nodoc:
     def initialize(phase_ctxt)
       super
       @fpath = phase_ctxt[:sources].first.fpath
-      traversal = phase_ctxt[:cc1_ast_traversal]
-      traversal.enter_ansi_function_definition  += T(:enter_function)
-      traversal.leave_ansi_function_definition  += T(:leave_function)
-      traversal.enter_kandr_function_definition += T(:enter_function)
-      traversal.leave_kandr_function_definition += T(:leave_function)
-      traversal.enter_if_else_statement         += T(:enter_if_else_statement)
-      traversal.leave_if_else_statement         += T(:leave_if_else_statement)
+      trav = phase_ctxt[:cc1_ast_traversal]
+      trav.enter_ansi_function_definition  += T(:enter_function)
+      trav.leave_ansi_function_definition  += T(:leave_function)
+      trav.enter_kandr_function_definition += T(:enter_function)
+      trav.leave_kandr_function_definition += T(:leave_function)
+      trav.enter_if_else_statement         += T(:enter_if_else_statement)
+      trav.leave_if_else_statement         += T(:leave_if_else_statement)
       @cur_fun = nil
       @if_else_stmt_chain = 0
       @incomplete_if_else_stmt_cnt = 0
@@ -545,11 +525,9 @@ module CBuiltin #:nodoc:
     def do_execute(*) end
 
     def enter_function(fun_def)
-      if @fpath == fun_def.location.fpath
-        @cur_fun = fun_def
-        @if_else_stmt_chain = 0
-        @incomplete_if_else_stmt_cnt = 0
-      end
+      @cur_fun = fun_def
+      @if_else_stmt_chain = 0
+      @incomplete_if_else_stmt_cnt = 0
     end
 
     def leave_function(*)
@@ -584,19 +562,19 @@ module CBuiltin #:nodoc:
     def initialize(phase_ctxt)
       super
       @fpath = phase_ctxt[:sources].first.fpath
-      traversal = phase_ctxt[:cc1_ast_traversal]
-      traversal.enter_ansi_function_definition  += T(:enter_function)
-      traversal.leave_ansi_function_definition  += T(:leave_function)
-      traversal.enter_kandr_function_definition += T(:enter_function)
-      traversal.leave_kandr_function_definition += T(:leave_function)
-      traversal.enter_compound_statement        += T(:enter_block)
-      traversal.leave_compound_statement        += T(:leave_block)
-      traversal.enter_if_statement              += T(:check_statement)
-      traversal.enter_if_else_statement         += T(:check_statement)
-      traversal.enter_while_statement           += T(:check_statement)
-      traversal.enter_do_statement              += T(:check_statement)
-      traversal.enter_for_statement             += T(:check_statement)
-      traversal.enter_c99_for_statement         += T(:check_statement)
+      trav = phase_ctxt[:cc1_ast_traversal]
+      trav.enter_ansi_function_definition  += T(:enter_function)
+      trav.leave_ansi_function_definition  += T(:leave_function)
+      trav.enter_kandr_function_definition += T(:enter_function)
+      trav.leave_kandr_function_definition += T(:leave_function)
+      trav.enter_compound_statement        += T(:enter_block)
+      trav.leave_compound_statement        += T(:leave_block)
+      trav.enter_if_statement              += T(:check_statement)
+      trav.enter_if_else_statement         += T(:check_statement)
+      trav.enter_while_statement           += T(:check_statement)
+      trav.enter_do_statement              += T(:check_statement)
+      trav.enter_for_statement             += T(:check_statement)
+      trav.enter_c99_for_statement         += T(:check_statement)
       @cur_fun = nil
     end
 
@@ -605,13 +583,11 @@ module CBuiltin #:nodoc:
     def do_execute(*) end
 
     def enter_function(fun_def)
-      if @fpath == fun_def.location.fpath
-        @cur_fun = fun_def
-        # NOTE: Nest level of the top of the function is 0.
-        #       Function definition must have a compound-statement as the
-        #       function body.
-        @max_nest_level = @cur_nest_level = -1
-      end
+      @cur_fun = fun_def
+      # NOTE: Nest level of the top of the function is 0.
+      #       Function definition must have a compound-statement as the
+      #       function body.
+      @max_nest_level = @cur_nest_level = -1
     end
 
     def leave_function(fun_def)
@@ -682,18 +658,15 @@ module CBuiltin #:nodoc:
     def do_execute(*) end
 
     def enter_function(fun_def, *)
-      if @fpath == fun_def.location.fpath
-        @cur_fun = fun_def
-
-        # NOTE: Number of paths in the current function.
-        @paths_in_fun = 1
-        # NOTE: Stack of the number of paths to enter the current branch group.
-        @paths_to_enter_branch_group = [@paths_in_fun]
-        # NOTE: Stack of the number of paths in the current branch.
-        @paths_in_branch = [@paths_in_fun]
-        # NOTE: Stack of the number of paths in the current branch group.
-        @paths_in_branch_group = [@paths_in_fun]
-      end
+      @cur_fun = fun_def
+      # NOTE: Number of paths in the current function.
+      @paths_in_fun = 1
+      # NOTE: Stack of the number of paths to enter the current branch group.
+      @paths_to_enter_branch_group = [@paths_in_fun]
+      # NOTE: Stack of the number of paths in the current branch.
+      @paths_in_branch = [@paths_in_fun]
+      # NOTE: Stack of the number of paths in the current branch group.
+      @paths_in_branch_group = [@paths_in_fun]
     end
 
     def leave_function(*)
@@ -752,14 +725,14 @@ module CBuiltin #:nodoc:
     def initialize(phase_ctxt)
       super
       @fpath = phase_ctxt[:sources].first.fpath
-      traversal = phase_ctxt[:cc1_ast_traversal]
-      traversal.enter_ansi_function_definition  += T(:enter_function)
-      traversal.leave_ansi_function_definition  += T(:leave_function)
-      traversal.enter_kandr_function_definition += T(:enter_function)
-      traversal.leave_kandr_function_definition += T(:leave_function)
-      traversal.enter_if_statement              += T(:enter_selection)
-      traversal.enter_if_else_statement         += T(:enter_selection)
-      traversal.enter_case_labeled_statement    += T(:enter_selection)
+      trav = phase_ctxt[:cc1_ast_traversal]
+      trav.enter_ansi_function_definition  += T(:enter_function)
+      trav.leave_ansi_function_definition  += T(:leave_function)
+      trav.enter_kandr_function_definition += T(:enter_function)
+      trav.leave_kandr_function_definition += T(:leave_function)
+      trav.enter_if_statement              += T(:enter_selection)
+      trav.enter_if_else_statement         += T(:enter_selection)
+      trav.enter_case_labeled_statement    += T(:enter_selection)
       @cur_fun = nil
       @cycl_compl = 0
     end
@@ -769,10 +742,8 @@ module CBuiltin #:nodoc:
     def do_execute(*) end
 
     def enter_function(fun_def)
-      if @fpath == fun_def.location.fpath
-        @cur_fun = fun_def
-        @cycl_compl = 0
-      end
+      @cur_fun = fun_def
+      @cycl_compl = 0
     end
 
     def leave_function(*)
