@@ -1,7 +1,7 @@
 # Code checkings (cpp-phase) of adlint-exam-c_builtin package.
 #
 # Author::    Yutaka Yanoh <mailto:yanoh@users.sourceforge.net>
-# Copyright:: Copyright (C) 2010-2013, OGIS-RI Co.,Ltd.
+# Copyright:: Copyright (C) 2010-2014, OGIS-RI Co.,Ltd.
 # License::   GPLv3+: GNU General Public License version 3 or later
 #
 # Owner::     Yutaka Yanoh <mailto:yanoh@users.sourceforge.net>
@@ -11,7 +11,7 @@
 #    /   |  / _  |/ /   / / | / /__  __/           Source Code Static Analyzer
 #   / /| | / / / / /   / /  |/ /  / /                   AdLint - Advanced Lint
 #  / __  |/ /_/ / /___/ / /|  /  / /
-# /_/  |_|_____/_____/_/_/ |_/  /_/   Copyright (C) 2010-2013, OGIS-RI Co.,Ltd.
+# /_/  |_|_____/_____/_/_/ |_/  /_/   Copyright (C) 2010-2014, OGIS-RI Co.,Ltd.
 #
 # This file is part of AdLint.
 #
@@ -48,9 +48,9 @@ module CBuiltin #:nodoc:
 
     def initialize(phase_ctxt)
       super
-      traversal = phase_ctxt[:cpp_ast_traversal]
-      traversal.enter_grouped_expression += T(:enter_grouped_expression)
-      traversal.leave_grouped_expression += T(:leave_grouped_expression)
+      trav = phase_ctxt[:cpp_ast_traversal]
+      trav.enter_grouped_expression += T(:enter_grouped_expression)
+      trav.leave_grouped_expression += T(:leave_grouped_expression)
       @group_depth = 0
     end
 
@@ -155,9 +155,9 @@ module CBuiltin #:nodoc:
 
     def initialize(phase_ctxt)
       super
-      traversal = phase_ctxt[:cpp_ast_traversal]
-      traversal.enter_if_section += T(:enter_if_section)
-      traversal.leave_if_section += T(:leave_if_section)
+      trav = phase_ctxt[:cpp_ast_traversal]
+      trav.enter_if_section += T(:enter_if_section)
+      trav.leave_if_section += T(:leave_if_section)
       @if_depth = 0
     end
 
@@ -355,9 +355,9 @@ module CBuiltin #:nodoc:
 
     def initialize(phase_ctxt)
       super
-      traversal = phase_ctxt[:cpp_ast_traversal]
-      traversal.enter_user_include_line   += T(:check_user_include_line)
-      traversal.enter_system_include_line += T(:check_system_include_line)
+      trav = phase_ctxt[:cpp_ast_traversal]
+      trav.enter_user_include_line   += T(:check_user_include_line)
+      trav.enter_system_include_line += T(:check_system_include_line)
     end
 
     private
@@ -383,11 +383,11 @@ module CBuiltin #:nodoc:
 
     def initialize(phase_ctxt)
       super
-      traversal = phase_ctxt[:cpp_ast_traversal]
-      traversal.enter_user_include_line   += T(:enter_include_line)
-      traversal.enter_system_include_line += T(:enter_include_line)
-      traversal.enter_text_line           += T(:enter_text_line)
-      traversal.enter_if_section          += T(:enter_if_section)
+      trav = phase_ctxt[:cpp_ast_traversal]
+      trav.enter_user_include_line   += T(:enter_include_line)
+      trav.enter_system_include_line += T(:enter_include_line)
+      trav.enter_text_line           += T(:enter_text_line)
+      trav.enter_if_section          += T(:enter_if_section)
       @main_fpath = phase_ctxt[:sources].first.fpath
       @last_fpath = nil
       @enclosed_by_if_section = false
@@ -496,9 +496,9 @@ module CBuiltin #:nodoc:
 
     def initialize(phase_ctxt)
       super
-      traversal = phase_ctxt[:cpp_ast_traversal]
-      traversal.enter_function_like_define_line    += T(:check)
-      traversal.enter_va_function_like_define_line += T(:check)
+      trav = phase_ctxt[:cpp_ast_traversal]
+      trav.enter_function_like_define_line    += T(:check)
+      trav.enter_va_function_like_define_line += T(:check)
     end
 
     private
@@ -663,10 +663,10 @@ module CBuiltin #:nodoc:
 
     def initialize(phase_ctxt)
       super
-      traversal = phase_ctxt[:cpp_ast_traversal]
-      traversal.enter_object_like_define_line      += T(:check)
-      traversal.enter_function_like_define_line    += T(:check)
-      traversal.enter_va_function_like_define_line += T(:check)
+      trav = phase_ctxt[:cpp_ast_traversal]
+      trav.enter_object_like_define_line      += T(:check)
+      trav.enter_function_like_define_line    += T(:check)
+      trav.enter_va_function_like_define_line += T(:check)
     end
 
     private
@@ -693,8 +693,8 @@ module CBuiltin #:nodoc:
 
     def initialize(phase_ctxt)
       super
-      traversal = phase_ctxt[:cpp_ast_traversal]
-      traversal.enter_object_like_define_line += T(:check)
+      trav = phase_ctxt[:cpp_ast_traversal]
+      trav.enter_object_like_define_line += T(:check)
     end
 
     private
@@ -716,10 +716,10 @@ module CBuiltin #:nodoc:
 
     def initialize(phase_ctxt)
       super
-      traversal = phase_ctxt[:cpp_ast_traversal]
-      traversal.enter_object_like_define_line      += T(:check)
-      traversal.enter_function_like_define_line    += T(:check)
-      traversal.enter_va_function_like_define_line += T(:check)
+      trav = phase_ctxt[:cpp_ast_traversal]
+      trav.enter_object_like_define_line      += T(:check)
+      trav.enter_function_like_define_line    += T(:check)
+      trav.enter_va_function_like_define_line += T(:check)
     end
 
     private
@@ -741,10 +741,10 @@ module CBuiltin #:nodoc:
 
     def initialize(phase_ctxt)
       super
-      traversal = phase_ctxt[:cpp_ast_traversal]
-      traversal.enter_object_like_define_line      += T(:check)
-      traversal.enter_function_like_define_line    += T(:check)
-      traversal.enter_va_function_like_define_line += T(:check)
+      trav = phase_ctxt[:cpp_ast_traversal]
+      trav.enter_object_like_define_line      += T(:check)
+      trav.enter_function_like_define_line    += T(:check)
+      trav.enter_va_function_like_define_line += T(:check)
     end
 
     private
@@ -764,8 +764,8 @@ module CBuiltin #:nodoc:
 
     def initialize(phase_ctxt)
       super
-      traversal = phase_ctxt[:cpp_ast_traversal]
-      traversal.enter_object_like_define_line += T(:check)
+      trav = phase_ctxt[:cpp_ast_traversal]
+      trav.enter_object_like_define_line += T(:check)
     end
 
     private
@@ -801,8 +801,8 @@ module CBuiltin #:nodoc:
 
     def initialize(phase_ctxt)
       super
-      traversal = phase_ctxt[:cpp_ast_traversal]
-      traversal.enter_object_like_define_line += T(:check)
+      trav = phase_ctxt[:cpp_ast_traversal]
+      trav.enter_object_like_define_line += T(:check)
     end
 
     private
@@ -1066,9 +1066,9 @@ module CBuiltin #:nodoc:
 
     def initialize(phase_ctxt)
       super
-      traversal = phase_ctxt[:cpp_ast_traversal]
-      traversal.enter_system_include_line      += T(:check)
-      traversal.enter_system_include_next_line += T(:check)
+      trav = phase_ctxt[:cpp_ast_traversal]
+      trav.enter_system_include_line      += T(:check)
+      trav.enter_system_include_next_line += T(:check)
     end
 
     private
@@ -1088,9 +1088,9 @@ module CBuiltin #:nodoc:
 
     def initialize(phase_ctxt)
       super
-      traversal = phase_ctxt[:cpp_ast_traversal]
-      traversal.enter_user_include_line      += T(:check)
-      traversal.enter_user_include_next_line += T(:check)
+      trav = phase_ctxt[:cpp_ast_traversal]
+      trav.enter_user_include_line      += T(:check)
+      trav.enter_user_include_next_line += T(:check)
     end
 
     private
@@ -1110,11 +1110,11 @@ module CBuiltin #:nodoc:
 
     def initialize(phase_ctxt)
       super
-      traversal = phase_ctxt[:cpp_ast_traversal]
-      traversal.enter_user_include_line        += T(:check)
-      traversal.enter_user_include_next_line   += T(:check)
-      traversal.enter_system_include_line      += T(:check)
-      traversal.enter_system_include_next_line += T(:check)
+      trav = phase_ctxt[:cpp_ast_traversal]
+      trav.enter_user_include_line        += T(:check)
+      trav.enter_user_include_next_line   += T(:check)
+      trav.enter_system_include_line      += T(:check)
+      trav.enter_system_include_next_line += T(:check)
     end
 
     private
@@ -1144,6 +1144,94 @@ module CBuiltin #:nodoc:
     end
   end
 
+  class W0687 < PassiveCodeCheck
+    def_registrant_phase Cpp::Prepare2Phase
+
+    # NOTE: W0687 may be duplicative when the same header which causes this
+    #       warning is included twice or more.
+    mark_as_unique
+
+    def initialize(phase_ctxt)
+      super
+      interp = phase_ctxt[:cpp_interpreter]
+      interp.on_macro_undefined += T(:check)
+    end
+
+    private
+    def check(undef_line, *)
+      if undef_line.identifier.value == "defined"
+        W(undef_line.identifier.location)
+      end
+    end
+  end
+
+  class W0688 < PassiveCodeCheck
+    def_registrant_phase Cpp::Prepare2Phase
+
+    # NOTE: W0688 may be duplicative when the same header which causes this
+    #       warning is included twice or more.
+    mark_as_unique
+
+    def initialize(phase_ctxt)
+      super
+      trav = phase_ctxt[:cpp_ast_traversal]
+      trav.enter_line_line += T(:check)
+    end
+
+    private
+    def check(line_line)
+      if line_no_arg = line_no_argument(line_line)
+        line_no = Integer(line_no_arg.value)
+        unless line_no > 0 && line_no < 32768
+          W(line_no_arg.location)
+        end
+      end
+    rescue
+    end
+
+    def line_no_argument(line_line)
+      line_line.pp_tokens ? line_line.pp_tokens.tokens.first : nil
+    end
+  end
+
+  class W0689 < W0688
+    def_registrant_phase Cpp::Prepare2Phase
+
+    # NOTE: W0689 may be duplicative when the same header which causes this
+    #       warning is included twice or more.
+    mark_as_unique
+
+    private
+    def check(line_line)
+      if fname_arg = file_name_argument(line_line)
+        unless fname_arg.value =~ /\A".*"\z/
+          W(fname_arg.location)
+        end
+      end
+    end
+
+    def file_name_argument(line_line)
+      line_line.pp_tokens ? line_line.pp_tokens.tokens[1] : nil
+    end
+  end
+
+  class W0690 < W0688
+    def_registrant_phase Cpp::Prepare2Phase
+
+    # NOTE: W0690 may be duplicative when the same header which causes this
+    #       warning is included twice or more.
+    mark_as_unique
+
+    private
+    def check(line_line)
+      if line_no_arg = line_no_argument(line_line)
+        Integer(line_no_arg.value)
+      end
+    rescue
+      W(line_no_arg.location)
+    end
+  end
+
   class W0691 < PassiveCodeCheck
     def_registrant_phase Cpp::Prepare2Phase
 
@@ -1186,6 +1274,21 @@ module CBuiltin #:nodoc:
     end
   end
 
+  class W0695 < W0687
+    def_registrant_phase Cpp::Prepare2Phase
+
+    # NOTE: W0695 may be duplicative when the same header which causes this
+    #       warning is included twice or more.
+    mark_as_unique
+
+    private
+    def check(undef_line, *)
+      if undef_line.identifier.value == "assert"
+        W(undef_line.identifier.location)
+      end
+    end
+  end
+
   class W0696 < PassiveCodeCheck
     def_registrant_phase Cpp::Prepare2Phase
 
@@ -1238,6 +1341,64 @@ module CBuiltin #:nodoc:
     end
   end
 
+  class W0806 < PassiveCodeCheck
+    def_registrant_phase Cpp::Prepare2Phase
+
+    # NOTE: W0806 may be duplicative when the same header which causes this
+    #       warning is included twice or more.
+    mark_as_unique
+
+    def initialize(phase_ctxt)
+      super
+      interp = phase_ctxt[:cpp_interpreter]
+      interp.on_object_like_macro_defined += T(:check)
+    end
+
+    private
+    def check(define_line, *)
+      if define_line.identifier.value == "defined"
+        W(define_line.identifier.location)
+      end
+    end
+  end
+
+  class W0807 < W0687
+    def_registrant_phase Cpp::Prepare2Phase
+
+    # NOTE: W0807 may be duplicative when the same header which causes this
+    #       warning is included twice or more.
+    mark_as_unique
+
+    private
+    def check(undef_line, macro)
+      if macro.kind_of?(Cpp::SpecialMacro)
+        identifier = undef_line.identifier
+        W(identifier.location, identifier.value)
+      end
+    end
+  end
+
+  class W0808 < PassiveCodeCheck
+    def_registrant_phase Cpp::Prepare2Phase
+
+    # NOTE: W0808 may be duplicative when the same header which causes this
+    #       warning is included twice or more.
+    mark_as_unique
+
+    def initialize(phase_ctxt)
+      super
+      interp = phase_ctxt[:cpp_interpreter]
+      interp.on_object_like_macro_defined += T(:check)
+      @macro_tbl = phase_ctxt[:cpp_macro_table]
+    end
+
+    private
+    def check(define_line, *)
+      id = define_line.identifier
+      W(id.location, id.value) if @macro_tbl.lookup(id.value)
+    end
+  end
+
   class W0811 < PassiveCodeCheck
     def_registrant_phase Cpp::Prepare2Phase
 
@@ -1327,8 +1488,8 @@ module CBuiltin #:nodoc:
 
     def initialize(phase_ctxt)
       super
-      traversal = phase_ctxt[:cpp_ast_traversal]
-      traversal.enter_unknown_directive += T(:check)
+      trav = phase_ctxt[:cpp_ast_traversal]
+      trav.enter_unknown_directive += T(:check)
     end
 
     private
