@@ -1,7 +1,7 @@
 # C typedef models for cross module analysis.
 #
 # Author::    Yutaka Yanoh <mailto:yanoh@users.sourceforge.net>
-# Copyright:: Copyright (C) 2010-2013, OGIS-RI Co.,Ltd.
+# Copyright:: Copyright (C) 2010-2014, OGIS-RI Co.,Ltd.
 # License::   GPLv3+: GNU General Public License version 3 or later
 #
 # Owner::     Yutaka Yanoh <mailto:yanoh@users.sourceforge.net>
@@ -11,7 +11,7 @@
 #    /   |  / _  |/ /   / / | / /__  __/           Source Code Static Analyzer
 #   / /| | / / / / /   / /  |/ /  / /                   AdLint - Advanced Lint
 #  / __  |/ /_/ / /___/ / /|  /  / /
-# /_/  |_|_____/_____/_/_/ |_/  /_/   Copyright (C) 2010-2013, OGIS-RI Co.,Ltd.
+# /_/  |_|_____/_____/_/_/ |_/  /_/   Copyright (C) 2010-2014, OGIS-RI Co.,Ltd.
 #
 # This file is part of AdLint.
 #
@@ -91,12 +91,13 @@ module Ld #:nodoc:
     def execute(met_fpath)
       sma_wd = Pathname.pwd
       CSV.foreach(met_fpath) do |csv_row|
-        rec = MetricRecord.of(csv_row, sma_wd)
-        case
-        when rec.version?
-          sma_wd = Pathname.new(rec.exec_working_directory)
-        when rec.typedef_declaration?
-          @map.add(Typedef.new(rec.type_name, rec.location))
+        if rec = MetricRecord.of(csv_row, sma_wd)
+          case
+          when rec.version?
+            sma_wd = Pathname.new(rec.exec_working_directory)
+          when rec.typedef_declaration?
+            @map.add(Typedef.new(rec.type_name, rec.location))
+          end
         end
       end
     end
