@@ -1,7 +1,7 @@
 # Analysis report and its manipulation utility.
 #
 # Author::    Yutaka Yanoh <mailto:yanoh@users.sourceforge.net>
-# Copyright:: Copyright (C) 2010-2013, OGIS-RI Co.,Ltd.
+# Copyright:: Copyright (C) 2010-2014, OGIS-RI Co.,Ltd.
 # License::   GPLv3+: GNU General Public License version 3 or later
 #
 # Owner::     Yutaka Yanoh <mailto:yanoh@users.sourceforge.net>
@@ -11,7 +11,7 @@
 #    /   |  / _  |/ /   / / | / /__  __/           Source Code Static Analyzer
 #   / /| | / / / / /   / /  |/ /  / /                   AdLint - Advanced Lint
 #  / __  |/ /_/ / /___/ / /|  /  / /
-# /_/  |_|_____/_____/_/_/ |_/  /_/   Copyright (C) 2010-2013, OGIS-RI Co.,Ltd.
+# /_/  |_|_____/_____/_/_/ |_/  /_/   Copyright (C) 2010-2014, OGIS-RI Co.,Ltd.
 #
 # This file is part of AdLint.
 #
@@ -432,7 +432,7 @@ module AdLint #:nodoc:
     # Writes a function cross reference information on the report.
     #
     # Abbreviation below is available.
-    #  write_xref_function(...) => XREF_FUNC(...)
+    #  write_xref_function(...) => XREF_FUN(...)
     #
     # === PARAMETER
     # _loc_:: Location -- Location where the cross-ref appears.
@@ -445,7 +445,7 @@ module AdLint #:nodoc:
     def write_xref_function(loc, referrer, ref_type, fun)
       write_code_struct(XRefFun.new(loc, referrer, ref_type, fun))
     end
-    alias :XREF_FUNC :write_xref_function
+    alias :XREF_FUN :write_xref_function
 
     def write_literal(loc, lit_type, prefix, suffix, value)
       write_code_struct(Literal.new(loc, lit_type, prefix, suffix, value))
