@@ -1,17 +1,17 @@
 # Unit specification of AST of C language.
 #
-# Author::    Rie Shima <mailto:rkakuuchi@users.sourceforge.net>
-# Copyright:: Copyright (C) 2010-2013, OGIS-RI Co.,Ltd.
+# Author::    Yutaka Yanoh <mailto:yanoh@users.sourceforge.net>
+# Copyright:: Copyright (C) 2010-2014, OGIS-RI Co.,Ltd.
 # License::   GPLv3+: GNU General Public License version 3 or later
 #
-# Owner::     Rie Shima <mailto:rkakuuchi@users.sourceforge.net>
+# Owner::     Yutaka Yanoh <mailto:yanoh@users.sourceforge.net>
 
 #--
 #     ___    ____  __    ___   _________
 #    /   |  / _  |/ /   / / | / /__  __/           Source Code Static Analyzer
 #   / /| | / / / / /   / /  |/ /  / /                   AdLint - Advanced Lint
 #  / __  |/ /_/ / /___/ / /|  /  / /
-# /_/  |_|_____/_____/_/_/ |_/  /_/   Copyright (C) 2010-2013, OGIS-RI Co.,Ltd.
+# /_/  |_|_____/_____/_/_/ |_/  /_/   Copyright (C) 2010-2014, OGIS-RI Co.,Ltd.
 #
 # This file is part of AdLint.
 #
@@ -591,7 +591,7 @@ module Cc1
     private
     def comma_separated_expression(*exprs)
       CommaSeparatedExpression.new(exprs.first).tap do |obj|
-        exprs[1..-1].each { |expr| obj.push(expr) }
+        exprs.drop(1).each { |expr| obj.push(expr) }
       end
     end
 
